summaryrefslogtreecommitdiffstats
path: root/libksirtet/lib/pline.h
diff options
context:
space:
mode:
Diffstat (limited to 'libksirtet/lib/pline.h')
-rw-r--r--libksirtet/lib/pline.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libksirtet/lib/pline.h b/libksirtet/lib/pline.h
index 9cef8d29..5bba6c4b 100644
--- a/libksirtet/lib/pline.h
+++ b/libksirtet/lib/pline.h
@@ -20,7 +20,7 @@ class MeetingLine : public TQFrame
public:
MeetingLine(bool isOwner, bool readerIsServer, bool serverLine,
- TQWidget *tqparent, const char *name = 0);
+ TQWidget *parent, const char *name = 0);
MeetingCheckBox::Type type() const { return tcb->type(); }
void setType(MeetingCheckBox::Type type) { tcb->setType(type); }
@@ -58,7 +58,7 @@ class PlayerLine : public TQFrame
PlayerLine(PlayerComboBox::Type type, const TQString &txt,
bool humanSetting, bool AISetting,
bool canBeEmpty, bool acceptAI,
- TQWidget *tqparent = 0, const char *name = 0);
+ TQWidget *parent = 0, const char *name = 0);
PlayerComboBox::Type type() const { return pcb->type(); }
TQString name() const { return edit->text(); }
@@ -86,13 +86,13 @@ class GWidgetList : public TQWidget
TQ_OBJECT
public:
- GWidgetList(uint interval, TQWidget *tqparent = 0, const char * name = 0);
+ GWidgetList(uint interval, TQWidget *parent = 0, const char * name = 0);
void remove(uint i);
uint size() const { return widgets.count(); }
protected:
/** The widget must be created with this widget as tqparent. */
void append(TQWidget *);
TQWidget *widget(uint i) { return widgets.at(i); }
@@ -105,8 +105,8 @@ template <class Type>
class WidgetList : public GWidgetList
{
public:
- WidgetList(uint interval, TQWidget *tqparent=0, const char *name=0)
- : GWidgetList(interval, tqparent, name) {}
+ WidgetList(uint interval, TQWidget *parent=0, const char *name=0)
+ : GWidgetList(interval, parent, name) {}
void append(Type *w) { GWidgetList::append(w); }
Type *widget(uint i) { return (Type *)GWidgetList::widget(i); }
@@ -86,13 +86,13 @@ class GWidgetList : public TQWidget
uint size() const { return widgets.count(); }
protected:
- /** The widget must be created with this widget as tqparent. */
+ /** The widget must be created with this widget as parent. */
void append(TQWidget *);
TQWidget *widget(uint i) { return widgets.at(i); }